# YtmUrl

## Installation

```
pip install ytmurl
```

## Usage

```
ytmurl [-h] [-l LOG] [-d FROM TO] query

searches youtube music and prints audio url

positional arguments:
  query                 query string containing title, artist, etc

optional arguments:
  -h, --help            show this help message and exit
  -l LOG, --log-file LOG
                        log file to append to
  -d FROM TO, --duration FROM TO
                        duration range of song in seconds, inclusive
```
